@@ -1328,22 +1328,25 @@ class Utilities:
                     hyper_cube_amount = 0
                 precision = 4**hyper_cube_amount
                 
-                x = field_sample[0]/(2*precision)
-                y = field_sample[1]/(2*precision)
-                z = field_sample[2]/(2*precision)
+                a = math.sqrt(field_sample[0]*field_sample[0] + field_sample[1]*field_sample[1])
+                ep = (field_sample[0] + 1j*field_sample[1])/a
+                a = a/precision
 
-                cx = math.cos(x)
-                sx = math.sin(x)
-                cy = math.cos(y)
-                sy = math.sin(y)
+                Ca = math.cos(a/2)
 
-                cisz = math.cos(z) + 1j*math.sin(z)
+                Sa = -1j*math.sin(a/2)
 
-                result[0, 0] = (cx*cy - 1j*sx*sy)/cisz
-                result[1, 0] = (cx*sy -1j*sx*cy)/cisz
+                ez = field_sample[2]/(2*precision)
+                ez = math.cos(ez) + 1j*math.sin(ez)
 
-                result[0, 1] = -(cx*sy + 1j*sx*cy)*cisz
-                result[1, 1] = (cx*cy + 1j*sx*sy)*cisz
+                eq = field_sample[3]/(6*precision)
+                eq = math.cos(eq) + 1j*math.sin(eq)
+
+                result[0, 0] = Ca/ez
+                result[1, 0] = Sa*ep
+
+                result[0, 1] = Sa/ep
+                result[1, 1] = Ca*ez
 
                 if device_index == 0:
                     temporary = np.empty((2, 2), dtype = np.complex128)
@@ -1356,6 +1359,41 @@ class Utilities:
                     matrix_multiply(result, result, temporary)
                     matrix_multiply(temporary, temporary, result)
 
+            # @jit_device
+            # def matrix_exponential_lie_trotter(field_sample, result, trotter_cutoff):
+            #     hyper_cube_amount = math.ceil(trotter_cutoff/2)
+            #     if hyper_cube_amount < 0:
+            #         hyper_cube_amount = 0
+            #     precision = 4**hyper_cube_amount
+                
+            #     x = field_sample[0]/(2*precision)
+            #     y = field_sample[1]/(2*precision)
+            #     z = field_sample[2]/(2*precision)
+
+            #     cx = math.cos(x)
+            #     sx = math.sin(x)
+            #     cy = math.cos(y)
+            #     sy = math.sin(y)
+
+            #     cisz = math.cos(z) + 1j*math.sin(z)
+
+            #     result[0, 0] = (cx*cy - 1j*sx*sy)/cisz
+            #     result[1, 0] = (cx*sy -1j*sx*cy)/cisz
+
+            #     result[0, 1] = -(cx*sy + 1j*sx*cy)*cisz
+            #     result[1, 1] = (cx*cy + 1j*sx*sy)*cisz
+
+            #     if device_index == 0:
+            #         temporary = np.empty((2, 2), dtype = np.complex128)
+            #     elif device_index == 1:
+            #         temporary = cuda.local.array((2, 2), dtype = np.complex128)
+            #     elif device_index == 2:
+            #         temporary_group = roc.shared.array((threads_per_block, 2, 2), dtype = np.complex128)
+            #         temporary = temporary_group[roc.get_local_id(1), :, :]
+            #     for power_index in range(hyper_cube_amount):
+            #         matrix_multiply(result, result, temporary)
+            #         matrix_multiply(temporary, temporary, result)
+
         else:
             @jit_device
             def norm2(z):
@@ -1456,19 +1494,33 @@ class Utilities:
                 ep = (field_sample[0] + 1j*field_sample[1])/a
                 a = a/precision
 
-                Ca = math.cos(a/2)
+                # Ca = math.cos(a/2)
 
-                Sa = math.sin(a/2)
+                # Sa = math.sin(a/2)
 
-                ca = math.cos(a)
+                # ca = math.cos(a)
 
-                sa = -1j*math.sin(a)/sqrt2
+                # sa = -1j*math.sin(a)/sqrt2
+
+                # ez = field_sample[2]/(2*precision)
+                # ez = math.cos(ez) + 1j*math.sin(ez)
+
+                # eq = field_sample[3]/(6*precision)
+                # eq = math.cos(eq) + 1j*math.sin(eq)
+
+                Ca = 1
+
+                Sa = a/2
+
+                ca = 1
+
+                sa = -1j*a/sqrt2
 
                 ez = field_sample[2]/(2*precision)
-                ez = math.cos(ez) + 1j*math.sin(ez)
+                ez = 1 + 1j*ez
 
                 eq = field_sample[3]/(6*precision)
-                eq = math.cos(eq) + 1j*math.sin(eq)
+                eq = 1 + 1j*eq
 
                 result[0, 0] = (Ca/(eq*ez))*(Ca/(eq*ez))
                 result[1, 0] = sa*eq*ep/ez
